#include <QtGui/QApplication>
#include <QSqlRecord>
#include <QDateTime>
#include "storage.h"
#include "tables.h"
#include "pageviewerwindow.h"
#include "maemo5application.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    a.setApplicationName("penpen");

    qsrand(QDateTime::currentDateTime().toTime_t());

    Maemo5Application app;

    return app.exec();
}
